@@ -1,6 +1,6 @@
 use strict;
 use warnings;
-package Data::Hive::Store 1.014;
+package Data::Hive::Store 1.015;
 # ABSTRACT: a backend storage driver for Data::Hive
 
 use Carp ();
@@ -105,17 +105,17 @@ Data::Hive::Store - a backend storage driver for Data::Hive
 
 =head1 VERSION
 
-version 1.014
+version 1.015
 
 =head1 DESCRIPTION
 
 Data::Hive::Store is a generic interface to a backend store
 for Data::Hive.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has a long-term perl support period.  That means it will not
-require a version of perl released fewer than five years ago.
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -180,7 +180,7 @@ Hans Dieter Pearcey <hdp@cpan.org>
 
 =item *
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =back
 
