@@ -1,6 +1,6 @@
 use strict;
 use warnings;
-package Data::Hive::Store::Hash 1.014;
+package Data::Hive::Store::Hash 1.015;
 # ABSTRACT: store a hive in a flat hashref
 
 use parent 'Data::Hive::Store';
@@ -136,7 +136,7 @@ Data::Hive::Store::Hash - store a hive in a flat hashref
 
 =head1 VERSION
 
-version 1.014
+version 1.015
 
 =head1 DESCRIPTION
 
@@ -163,10 +163,10 @@ We would end up with C<$href> containing something like:
     'foo.bar.baz' => 2
   }
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has a long-term perl support period.  That means it will not
-require a version of perl released fewer than five years ago.
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -210,7 +210,7 @@ Hans Dieter Pearcey <hdp@cpan.org>
 
 =item *
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =back
 
