@@ -1,6 +1,6 @@
 use strict;
 use warnings;
-package Data::Hive::Store::Hash::Nested 1.014;
+package Data::Hive::Store::Hash::Nested 1.015;
 # ABSTRACT: store a hive in nested hashrefs
 
 use parent 'Data::Hive::Store';
@@ -247,7 +247,7 @@ Data::Hive::Store::Hash::Nested - store a hive in nested hashrefs
 
 =head1 VERSION
 
-version 1.014
+version 1.015
 
 =head1 DESCRIPTION
 
@@ -288,10 +288,10 @@ although fairly unlikely, that this format will change again.  The Hash store
 should generally be used for testing things that use a hive, as opposed for
 building hashes that will be used for anything else.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has a long-term perl support period.  That means it will not
-require a version of perl released fewer than five years ago.
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -334,7 +334,7 @@ Hans Dieter Pearcey <hdp@cpan.org>
 
 =item *
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =back
 
